==> 0.0.1%2B1.tar.gz: lib/models/IR5PointageResFmt2.dart <==
import 'package:json_annotation/json_annotation.dart';

import "ILedgerTbl.dart" show ILedgerTblSeq;
import "IR5Delivry.dart" show IR5Delivry;
import "IR5Member.dart" show IR5Member;

part 'IR5PointageResFmt2.g.dart';

// --------------------------------------------------------------------------------
@JsonSerializable(explicitToJson: true)
class IR5PointageResFmt2 {
  IR5PointageResFmt2({
    required this.NoTbl,
    required this.SsTbl,
    required this.Nom,
    required this.TblType,
    required this.Cvts,
    required this.TblMode,
    required this.TblIsEmport,
    required this.TblDivision,
    this.Notify,
    this.Descr,
    this.OUFTIState,
    this.DteOuv,
    this.DteClot,
    this.NoHre,
    this.NoSales,
    this.GUID,
    this.StationNum,
    this.StationFiscalId,
    this.ProprioNo,
    this.ProprioNom,
    this.MemberCard,
    this.Member,
    this.Delivry,
    this.Tariff,
    this.TariffIn,
    this.TariffOut,
    this.Details,
    this.Total,
    this.Base,
    this.Tax,
    this.EnCaisse,
  });

  factory IR5PointageResFmt2.fromJson(Map<String, dynamic>? json) => _$IR5PointageResFmt2FromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageResFmt2ToJson(this);

  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** TblType: 11 - Normal | 12 - Comptoir | 13 - V.Tbl Bar | 14 - Personnel | 15 - Traiteur | 16 - Taverne | 17 - Delivery | 18 - Pickup | 19 - Auto Inc | 20 - Type J | 91 - SplitAPart | 92 - EnCaisse */
  @JsonKey(defaultValue: 0)
  final num TblType;
  @JsonKey(defaultValue: 0)
  final num Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  @JsonKey(defaultValue: 0)
  final num TblMode;
  @JsonKey(defaultValue: false)
  final bool TblIsEmport;
  @JsonKey(defaultValue: 0)
  final num TblDivision;

  /** Who to Notify when Restomax will cloture the Tbl (Should be configured in Restomax.Etab.ProdCtrl ini section notify) */
  final String? Notify;

  /** MemberName|TblName|... Only in GetPointage Answer */
  final String? Descr;
  final String? OUFTIState;
  final String? DteOuv;
  final String? DteClot;
  final num? NoHre;
  final num? NoSales;
  final String? GUID;
  final num? StationNum;
  final String? StationFiscalId;
  final num? ProprioNo;
  final String? ProprioNom;

  /** Member NumCard. numéro identifiant le membre (alphanum) */
  final String? MemberCard;
  final IR5Member? Member;

  /** Delivry Or Take Away Info. */
  final IR5Delivry? Delivry;

  /** Tariff used / to use */
  final num? Tariff;
  final num? TariffIn;
  final num? TariffOut;
  final List<ILedgerTblSeq>? Details;

  /** Totals */
  final num? Total;
  final num? Base;
  final num? Tax;
  final num? EnCaisse;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5PointageResFmt2.dart <==
import 'package:json_annotation/json_annotation.dart';

import "ILedgerTbl.dart" show ILedgerTblSeq;
import "IR5Delivry.dart" show IR5Delivry;
import "IR5Member.dart" show IR5Member;

part 'IR5PointageResFmt2.g.dart';

// --------------------------------------------------------------------------------
@JsonSerializable(explicitToJson: true)
class IR5PointageResFmt2 {
  IR5PointageResFmt2({
    required this.NoTbl,
    required this.SsTbl,
    required this.Nom,
    required this.TblType,
    required this.Cvts,
    required this.TblMode,
    required this.TblIsEmport,
    required this.TblDivision,
    this.Notify,
    this.Descr,
    this.OUFTIState,
    this.DteOuv,
    this.DteClot,
    this.NoHre,
    this.NoSales,
    this.GUID,
    this.StationNum,
    this.StationFiscalId,
    this.ProprioNo,
    this.ProprioNom,
    this.MemberCard,
    this.Member,
    this.Delivry,
    this.Tariff,
    this.TariffIn,
    this.TariffOut,
    this.Details,
    this.Total,
    this.Base,
    this.Tax,
    this.EnCaisse,
  });

  factory IR5PointageResFmt2.fromJson(Map<String, dynamic>? json) =>
      _$IR5PointageResFmt2FromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageResFmt2ToJson(this);

  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** TblType: 11 - Normal | 12 - Comptoir | 13 - V.Tbl Bar | 14 - Personnel | 15 - Traiteur | 16 - Taverne | 17 - Delivery | 18 - Pickup | 19 - Auto Inc | 20 - Type J | 91 - SplitAPart | 92 - EnCaisse */
  @JsonKey(defaultValue: 0)
  final num TblType;
  @JsonKey(defaultValue: 0)
  final num Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  @JsonKey(defaultValue: 0)
  final num TblMode;
  @JsonKey(defaultValue: false)
  final bool TblIsEmport;
  @JsonKey(defaultValue: 0)
  final num TblDivision;

  /** Who to Notify when Restomax will cloture the Tbl (Should be configured in Restomax.Etab.ProdCtrl ini section notify) */
  final String? Notify;

  /** MemberName|TblName|... Only in GetPointage Answer */
  final String? Descr;
  final String? OUFTIState;
  final String? DteOuv;
  final String? DteClot;
  final num? NoHre;
  final num? NoSales;
  final String? GUID;
  final num? StationNum;
  final String? StationFiscalId;
  final num? ProprioNo;
  final String? ProprioNom;

  /** Member NumCard. numéro identifiant le membre (alphanum) */
  final String? MemberCard;
  final IR5Member? Member;

  /** Delivry Or Take Away Info. */
  final IR5Delivry? Delivry;

  /** Tariff used / to use */
  final num? Tariff;
  final num? TariffIn;
  final num? TariffOut;
  final List<ILedgerTblSeq>? Details;

  /** Totals */
  final num? Total;
  final num? Base;
  final num? Tax;
  final num? EnCaisse;
}
